:orphan:

Welcome to Flask-Collect-Invenio
================================

Welcome to Flask-Collect-Invenio's documentation.

.. == description ==
.. _description:

Flask-Collect-Invenio
---------------------

.. automodule:: flask_collect

.. == badges ==
.. _badges:
.. include:: ../README.rst
    :start-after: .. _badges:
    :end-before: .. _documentation:


User's Guide
------------

This part of the documentation will show you how to get started in using
Flask-Collect-Invenio.

.. toctree::
   :maxdepth: 2

   quickstart
   installation
   config


API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   api


.. == bugtracker ==
.. _bugtracker:
.. include:: ../README.rst
    :start-after: .. _bugtracker:
    :end-before: .. _contributing:


.. == contributing ==
.. _contributing:
.. include:: ../README.rst
    :start-after: .. _contributing:
    :end-before: .. _license:

.. == links ==
.. _links:
.. include:: ../README.rst
    :start-after: .. _links:
